<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
                xmlns:ijw="http://www.istandaarden.nl/ijw/3_0/basisschema/schema"
                xmlns:jw301="http://www.istandaarden.nl/ijw/3_0/jw301/schema"
>

    <!-- iJw 3.0 TR302 version 2.2.8 (2021-01-25) -->

    <xsl:import href="../common/basis.xsl"/>
    <xsl:template match="*" mode="TR302"/>
    <xsl:template match="*" mode="check">
        <xsl:apply-templates select="*" mode="TR302"/>
    </xsl:template>

    <xsl:template match="jw301:ToegewezenProduct" mode="TR302">
        <xsl:call-template name="tr302"/>
    </xsl:template>

    <xsl:template name="tr302">
        <xsl:param name="pThis" select="."/>
        <xsl:param name="pList" select="preceding-sibling::*"/>
        
        <xsl:variable name="vIgnoreSelf">
            <xsl:call-template name="ignoreForTR302" />
        </xsl:variable>

		<xsl:if test="$vIgnoreSelf != 'true'">
	        <xsl:for-each select="$pList">
		        <xsl:variable name="vIgnorePredecessor">
		            <xsl:call-template name="ignoreForTR302" />
		        </xsl:variable>
	            <xsl:if test="$vIgnorePredecessor != 'true' and (
	                                  (
								            ($pThis/jw301:Product/ijw:Code and current()/jw301:Product/ijw:Code and $pThis/jw301:Product/ijw:Code = current()/jw301:Product/ijw:Code) and
	                                        ($pThis/jw301:Product/ijw:Categorie and current()/jw301:Product/ijw:Categorie and $pThis/jw301:Product/ijw:Categorie = current()/jw301:Product/ijw:Categorie)
	                                  ) or 
	                                 (
	                                 		(not($pThis/jw301:Product/ijw:Code) or not(current()/jw301:Product/ijw:Code)) and
	                                        ($pThis/jw301:Product/ijw:Categorie and current()/jw301:Product/ijw:Categorie and $pThis/jw301:Product/ijw:Categorie = current()/jw301:Product/ijw:Categorie)
	                         		) or
	                         		(
	                                 		(not($pThis/jw301:Product/ijw:Code) and not($pThis/jw301:Product/ijw:Categorie)) or
	                                 		(not(current()/jw301:Product/ijw:Code) and not(current()/jw301:Product/ijw:Categorie))
	                         		)
	                                 )"> 
	                          
	                <xsl:variable name="isOverlay">
	                    <xsl:call-template name="isPeriodOverlay">
	                        <xsl:with-param name="pThis" select="$pThis"/>
	                        <xsl:with-param name="pOther" select="current()"/>
	                    </xsl:call-template>
	                </xsl:variable>
	                <xsl:if test="$isOverlay = 'true'">
	                    <xsl:call-template name="addError">
	                        <xsl:with-param name="pElements" select="$pThis | current()"/>
	                        <xsl:with-param name="pRule">TR302</xsl:with-param>
	                    </xsl:call-template>
	                </xsl:if>
	            </xsl:if>
	        </xsl:for-each>
        </xsl:if>
    </xsl:template>
    
    <xsl:template name="ignoreForTR302">
	    <xsl:param name="pThis" select="." />
	    
	    <xsl:choose>
		    <xsl:when test="jw301:RedenWijziging/text() = '01' and jw301:Einddatum/. and normalize-space(jw301:Einddatum/text()) != ''">
		    	<xsl:choose>
			    	<xsl:when test="translate(jw301:Ingangsdatum/text(), '-', '') = translate(jw301:Einddatum/text(), '-', '')">
				    	<xsl:value-of select="true()" />
			    	</xsl:when>
			    	<xsl:otherwise>
				    	<xsl:value-of select="false()" />
			    	</xsl:otherwise>
		    	</xsl:choose>
		    </xsl:when>
		    <xsl:otherwise>
			    <xsl:value-of select="false()" />
		    </xsl:otherwise>
	    </xsl:choose>
    </xsl:template>

</xsl:stylesheet>
