<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
	xmlns:ijw="http://www.istandaarden.nl/ijw/3_0/basisschema/schema"
	xmlns:jw303="http://www.istandaarden.nl/ijw/3_0/jw303/schema"
	xmlns:jw323="http://www.istandaarden.nl/ijw/3_0/jw323/schema"
	>

	<!-- iWw 3.0 TR316 version 2.2.8 (2021-01-25) -->

	<xsl:import href="../common/basis.xsl"/>
	<xsl:template match="*" mode="TR316"/>
	<xsl:template match="*" mode="check">
		<xsl:apply-templates select="*" mode="TR316"/>
	</xsl:template>

	<xsl:template match="jw303:ProductReferentie" mode="TR316">
		<xsl:variable name="vReferentieNummer" select="normalize-space(ijw:ReferentieNummer/text())" />
		<xsl:variable name="vVorigReferentieNummer" select="normalize-space(ijw:VorigReferentieNummer/text())" />
		<xsl:variable name="vReferentie" select="ijw:ReferentieNummer" />
		<xsl:variable name="vVorigReferentie" select="ijw:VorigReferentieNummer" />
		
		<xsl:for-each select="
				ancestor-or-self::jw303:Prestatie/preceding-sibling::jw303:Prestatie/jw303:ProductReferentie/ijw:ReferentieNummer[text() = $vVorigReferentieNummer] |
				ancestor-or-self::jw303:Client/preceding-sibling::jw303:Client/jw303:Prestaties/jw303:Prestatie/jw303:ProductReferentie/ijw:ReferentieNummer[text() = $vVorigReferentieNummer]
				">
			<xsl:call-template name="checkvalue">
				<xsl:with-param name="pValues">!#</xsl:with-param>
				<xsl:with-param name="pRule">TR316</xsl:with-param>
				<xsl:with-param name="pExtra" select="$vVorigReferentie" />
			</xsl:call-template>
		</xsl:for-each>
		
		<xsl:for-each select="
				ancestor-or-self::jw303:Prestatie/preceding-sibling::jw303:Prestatie/jw303:ProductReferentie/ijw:VorigReferentieNummer[text() = $vReferentieNummer] |
				ancestor-or-self::jw303:Client/preceding-sibling::jw303:Client/jw303:Prestaties/jw303:Prestatie/jw303:ProductReferentie/ijw:VorigReferentieNummer[text() = $vReferentieNummer]
				">
			<xsl:call-template name="checkvalue">
				<xsl:with-param name="pValues">!#</xsl:with-param>
				<xsl:with-param name="pRule">TR316</xsl:with-param>
				<xsl:with-param name="pExtra" select="$vReferentie" />
			</xsl:call-template>
		</xsl:for-each>

		<xsl:if test="$vReferentieNummer = $vVorigReferentieNummer">
			<xsl:call-template name="addError">
				<xsl:with-param name="pRule">TR316</xsl:with-param>
				<xsl:with-param name="pElements" select="ijw:ReferentieNummer | ijw:VorigReferentieNummer" />
			</xsl:call-template>
		</xsl:if>
	</xsl:template>

	<xsl:template match="jw323:ProductReferentie" mode="TR316">
		<xsl:variable name="vReferentieNummer" select="normalize-space(ijw:ReferentieNummer/text())" />
		<xsl:variable name="vVorigReferentieNummer" select="normalize-space(ijw:VorigReferentieNummer/text())" />
		<xsl:variable name="vReferentie" select="ijw:ReferentieNummer" />
		<xsl:variable name="vVorigReferentie" select="ijw:VorigReferentieNummer" />
		
		<xsl:for-each select="
				ancestor-or-self::jw323:Prestatie/preceding-sibling::jw323:Prestatie/jw323:ProductReferentie/ijw:ReferentieNummer[text() = $vVorigReferentieNummer] |
				ancestor-or-self::jw323:Client/preceding-sibling::jw323:Client/jw323:Prestaties/jw323:Prestatie/jw323:ProductReferentie/ijw:ReferentieNummer[text() = $vVorigReferentieNummer]
				">
			<xsl:call-template name="checkvalue">
				<xsl:with-param name="pValues">!#</xsl:with-param>
				<xsl:with-param name="pRule">TR316</xsl:with-param>
				<xsl:with-param name="pExtra" select="$vVorigReferentie" />
			</xsl:call-template>
		</xsl:for-each>
		
		<xsl:for-each select="
				ancestor-or-self::jw323:Prestatie/preceding-sibling::jw323:Prestatie/jw323:ProductReferentie/ijw:VorigReferentieNummer[text() = $vReferentieNummer] |
				ancestor-or-self::jw323:Client/preceding-sibling::jw323:Client/jw323:Prestaties/jw323:Prestatie/jw323:ProductReferentie/ijw:VorigReferentieNummer[text() = $vReferentieNummer]
				">
			<xsl:call-template name="checkvalue">
				<xsl:with-param name="pValues">!#</xsl:with-param>
				<xsl:with-param name="pRule">TR316</xsl:with-param>
				<xsl:with-param name="pExtra" select="$vReferentie" />
			</xsl:call-template>
		</xsl:for-each>
		
		<xsl:if test="$vReferentieNummer = $vVorigReferentieNummer">
			<xsl:call-template name="addError">
				<xsl:with-param name="pRule">TR316</xsl:with-param>
				<xsl:with-param name="pElements" select="ijw:ReferentieNummer | ijw:VorigReferentieNummer" />
			</xsl:call-template>
		</xsl:if>
	</xsl:template>

</xsl:stylesheet>
